Skip to contents

A function to parse bibliographic dataframes outputted from Rayyan, splitting up the 'notes' column into Inclusion/Exclusion decision, Labels, and Exclusion Reasons

Usage

parse_rayyan(rayyan_df)

Arguments

rayyan_df

A rayyan exported bibliography file

Value

A dataframe

Details

function (beta) to remove any old inclusion labels from abstract screening (found in the labels or parsed as html paragraphs)

References

Jones ML & Grainger MJ (2021). rayyanR: An R package to process outputs of the Rayyan screening platform for systematic reviews. https://github.com/befriendabacterium/rayyanR.

Author

Matt Lloyd Jones